==> jc-1.4.0.tar.gz: javax/swing/colorchooser/DefaultSwatchChooserPanel__24MainSwatchPanel.h <==
// class javax.swing.colorchooser.DefaultSwatchChooserPanel$MainSwatchPanel

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 7c0c9df11a59950c javax_swing_JPanel
// @dep_class 17f0c6f7b103adf9 javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel
// @dep_class 3146b457beeae28 javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel

// header file dependencies
// @dep_header javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel

#include "javax/swing/colorchooser/DefaultSwatchChooserPanel__24SwatchPanel.h"

#ifndef _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel_H_
#define _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$sub_refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object;

typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$fields_struct	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$fields_struct;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vmethods	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vtable	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vtype	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vtype;

// Class fields structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$fields_struct {
	struct _jc_java_awt_Color$object	*C000051051;
	struct _jc_java_awt_Color$object	*C000102102;
	struct _jc_java_awt_Color$object	*C000153153;
	struct _jc_java_awt_Color$object	*C000204204;
	struct _jc_java_awt_Color$object	*C051000051;
	struct _jc_java_awt_Color$object	*C051051000;
	struct _jc_java_awt_Color$object	*C051051255;
	struct _jc_java_awt_Color$object	*C051255051;
	struct _jc_java_awt_Color$object	*C102000102;
	struct _jc_java_awt_Color$object	*C102102000;
	struct _jc_java_awt_Color$object	*C102102255;
	struct _jc_java_awt_Color$object	*C102255102;
	struct _jc_java_awt_Color$object	*C153000153;
	struct _jc_java_awt_Color$object	*C153153000;
	struct _jc_java_awt_Color$object	*C153153255;
	struct _jc_java_awt_Color$object	*C153255153;
	struct _jc_java_awt_Color$object	*C204000204;
	struct _jc_java_awt_Color$object	*C204204000;
	struct _jc_java_awt_Color$object	*C204204204;
	struct _jc_java_awt_Color$object	*C204255204;
	struct _jc_java_awt_Color$object	*C204255255;
	struct _jc_java_awt_Color$object	*C255051051;
	struct _jc_java_awt_Color$object	*C255102102;
	struct _jc_java_awt_Color$object	*C255153153;
	struct _jc_java_awt_Color$object	*C255204204;
	_jc_object_array	*colors;
};
extern _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$fields_struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$class_fields;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object *);

// Virtual methods
extern struct _jc_java_awt_Color$object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$method$getColorForPosition$9e238dcc81583aa7(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object *, jint, jint);
extern struct _jc_java_lang_String$object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$method$getToolTipText$69909437751767f6(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object *, struct _jc_java_awt_event_MouseEvent$object *);
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$method$initializeColors$177c4c7d81450fda(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object *);
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object *, struct _jc_java_awt_Graphics$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$method_info$getColorForPosition$9e238dcc81583aa7;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$method_info$getToolTipText$69909437751767f6;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$method_info$initializeColors$177c4c7d81450fda;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$method_info$paint$76f038a09cf0c480;

// Static methods
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vmethods {
	struct _jc_java_awt_Color$object	*(*getColorForPosition$9e238dcc81583aa7)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object *, jint, jint);
	struct _jc_java_lang_String$object	*(*getToolTipText$69909437751767f6)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object *, struct _jc_java_awt_event_MouseEvent$object *);
	void	(*initializeColors$177c4c7d81450fda)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object *);
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object *, struct _jc_java_awt_Graphics$object *);
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JPanel$vmethods	javax_swing_JPanel;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vmethods	javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vmethods	javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$refs {
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$sub_refs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel;
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_refs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel;
    _jc_javax_swing_JPanel$sub_refs	javax_swing_JPanel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JPanel$sub_nonrefs	javax_swing_JPanel;
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_nonrefs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel;
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$sub_nonrefs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object {
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vtype _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel_H_ */

==> jc-1.4.5.tar.gz: javax/swing/colorchooser/DefaultSwatchChooserPanel__24MainSwatchPanel.h <==
// class javax.swing.colorchooser.DefaultSwatchChooserPanel$MainSwatchPanel

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class 7c0c9df11a59950c javax_swing_JPanel
// @dep_class 17f0c6f7b103adf9 javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel
// @dep_class 3146b457beeae28 javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel

// header file dependencies
// @dep_header javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel

#include "javax/swing/colorchooser/DefaultSwatchChooserPanel__24SwatchPanel.h"

#ifndef _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel_H_
#define _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_event_MouseEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$sub_refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$refs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$nonrefs	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object;

typedef struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$fields_struct	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$fields_struct;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vmethods	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vtable	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vtype	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vtype;

// Class fields structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$fields_struct {
	struct _jc_java_awt_Color$object	*C000051051;
	struct _jc_java_awt_Color$object	*C000102102;
	struct _jc_java_awt_Color$object	*C000153153;
	struct _jc_java_awt_Color$object	*C000204204;
	struct _jc_java_awt_Color$object	*C051000051;
	struct _jc_java_awt_Color$object	*C051051000;
	struct _jc_java_awt_Color$object	*C051051255;
	struct _jc_java_awt_Color$object	*C051255051;
	struct _jc_java_awt_Color$object	*C102000102;
	struct _jc_java_awt_Color$object	*C102102000;
	struct _jc_java_awt_Color$object	*C102102255;
	struct _jc_java_awt_Color$object	*C102255102;
	struct _jc_java_awt_Color$object	*C153000153;
	struct _jc_java_awt_Color$object	*C153153000;
	struct _jc_java_awt_Color$object	*C153153255;
	struct _jc_java_awt_Color$object	*C153255153;
	struct _jc_java_awt_Color$object	*C204000204;
	struct _jc_java_awt_Color$object	*C204204000;
	struct _jc_java_awt_Color$object	*C204204204;
	struct _jc_java_awt_Color$object	*C204255204;
	struct _jc_java_awt_Color$object	*C204255255;
	struct _jc_java_awt_Color$object	*C255051051;
	struct _jc_java_awt_Color$object	*C255102102;
	struct _jc_java_awt_Color$object	*C255153153;
	struct _jc_java_awt_Color$object	*C255204204;
	_jc_object_array	*colors;
};
extern _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$fields_struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$class_fields;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Color$object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$method$getColorForPosition$9e238dcc81583aa7(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object *, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$method$getToolTipText$69909437751767f6(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$method$initializeColors$177c4c7d81450fda(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$method$paint$76f038a09cf0c480(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$method_info$getColorForPosition$9e238dcc81583aa7;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$method_info$getToolTipText$69909437751767f6;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$method_info$initializeColors$177c4c7d81450fda;
extern _jc_method _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$method_info$paint$76f038a09cf0c480;

// Static methods
extern void _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vmethods {
	struct _jc_java_awt_Color$object	*(*getColorForPosition$9e238dcc81583aa7)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object *, jint, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getToolTipText$69909437751767f6)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object *, struct _jc_java_awt_event_MouseEvent$object *) _JC_JCNI_ATTR;
	void	(*initializeColors$177c4c7d81450fda)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object *) _JC_JCNI_ATTR;
	void	(*paint$76f038a09cf0c480)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object *, struct _jc_java_awt_Graphics$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JPanel$vmethods	javax_swing_JPanel;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$vmethods	javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vmethods	javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$refs {
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$sub_refs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel;
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_refs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel;
    _jc_javax_swing_JPanel$sub_refs	javax_swing_JPanel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JPanel$sub_nonrefs	javax_swing_JPanel;
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel$sub_nonrefs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24SwatchPanel;
    _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$sub_nonrefs	javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$object {
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$vtype _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultSwatchChooserPanel__24MainSwatchPanel_H_ */
